@@ -2,7 +2,7 @@ from .Customer import Customer
 from .Card import Card
 from .CardToken import CardToken
 from .Payment import Payment
-
+from .Refund import Refund
 
 class DecidirSDK:
     def __init__(self, merchant):
@@ -24,3 +24,6 @@ class DecidirSDK:
 
     def payment(self):
         return Payment(self.url, self.private_key, self.public_key)
+
+    def refund(self):
+        return Refund(self.url, self.private_key, self.public_key)
