@@ -66,10 +66,16 @@ class Payment:
             return ok(_format(response))
         return error(response)
 
-    def get(self, payment_id: int):
-        r = requests.get(self.url + '/payments/{}'.format(payment_id), headers=self.headers)
-        return ok(_format(r.json()))
-
+    def get(self, payment_id: str):
+        # r = requests.get(self.url + '/payments/{}'.format(payment_id), headers=self.headers)
+        # return ok(_format(r.json()))
+        filters = {'siteOperationId':payment_id}
+        r = requests.get(self.url + '/payments', params=filters, headers=self.headers)
+        list_results = r['response']['results']
+        if len(list_results) == 1:
+            return _format(list_results[0])
+        else:
+            return error('error_pago_no_encontrado')
     def search(self, filters: dict) -> dict:
         # El filter puede ser:
         # offset
